==> seedsui-react-5.7.93.tgz: package/lib/Tooltip/Tooltip.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["animation", "style", "getChildrenDOM", "children", "onVisibleChange"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useEffect, useImperativeHandle, useState } from 'react';
import Popup from "./Popup";
import Utils from "./Utils";
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Tooltip = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$animation = _ref.animation,
    animation = _ref$animation === void 0 ? 'slideDownLeft' : _ref$animation,
    style = _ref.style,
    getChildrenDOM = _ref.getChildrenDOM,
    children = _ref.children,
    onVisibleChange = _ref.onVisibleChange,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  var childrenRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });

  // 非受控显隐
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    visible = _useState2[0],
    setVisible = _useState2[1];

  // 受控显隐时, 需要更新容器位置
  useEffect(function () {
    if (visible) {
      updatePosition();
    }
    if (visible === null) return;
    typeof onVisibleChange === 'function' && onVisibleChange(visible);
  }, [visible]); // eslint-disable-line

  // 更新位置
  function updatePosition(source) {
    var _rootRef$current, _rootRef$current2, _rootRef$current3;
    // 源元素
    var sourceDOM = source;
    if (!sourceDOM) {
      var childrenDOM = childrenRef.current;
      if (typeof getChildrenDOM === 'function') {
        var _childrenDOM;
        childrenDOM = getChildrenDOM();
        if (typeof ((_childrenDOM = childrenDOM) === null || _childrenDOM === void 0 ? void 0 : _childrenDOM.getRootDOM) === 'function') {
          childrenDOM = childrenDOM.getRootDOM();
        }
      }
      sourceDOM = childrenDOM;
    }

    // 位移元素
    var targetDOM = rootRef !== null && rootRef !== void 0 && (_rootRef$current = rootRef.current) !== null && _rootRef$current !== void 0 && _rootRef$current.children && rootRef !== null && rootRef !== void 0 && (_rootRef$current2 = rootRef.current) !== null && _rootRef$current2 !== void 0 && _rootRef$current2.children[0] ? rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current3 = rootRef.current) === null || _rootRef$current3 === void 0 ? void 0 : _rootRef$current3.children[0] : null;
    if (sourceDOM && targetDOM) {
      // 没有自定义位置时生效
      if (!(style !== null && style !== void 0 && style.left) && !(style !== null && style !== void 0 && style.top) && !(style !== null && style !== void 0 && style.right) && !(style !== null && style !== void 0 && style.bottom)) {
        Utils.updateContainerPosition({
          source: sourceDOM,
          target: targetDOM,
          animation: animation,
          offset: {
            top: 8,
            bottom: 8
          }
        });
      }
    }
  }

  // 非受控显隐, 为子元素增加点击事件显隐
  var newChildren = React.Children.toArray(children);
  if (newChildren.length === 1) {
    newChildren = /*#__PURE__*/React.cloneElement(children, {
      ref: childrenRef,
      onClick: function onClick(e) {
        // 没有自定义位置时生效
        if (!(style !== null && style !== void 0 && style.left) && !(style !== null && style !== void 0 && style.top) && !(style !== null && style !== void 0 && style.right) && !(style !== null && style !== void 0 && style.bottom)) {
          updatePosition(e.currentTarget);
        }
        setVisible(!visible);
      }
    });
  } else {
    newChildren = children;
  }
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(Popup, _objectSpread(_objectSpread({
      animation: animation,
      style: style,
      visible: typeof visible === 'boolean' ? visible : visible,
      onVisibleChange: function onVisibleChange(newVisible) {
        if (!newVisible) {
          setVisible(newVisible);
        }
      }
    }, props), {}, {
      ref: rootRef
    })), newChildren]
  });
});
export default Tooltip;

==> seedsui-react-5.8.44.tgz: package/lib/Tooltip/Tooltip.js <==
var _excluded = ["animation", "style", "getChildrenDOM", "children", "onVisibleChange"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useEffect, useImperativeHandle, useState } from 'react';
import Popup from "./Popup";
import Utils from "./Utils";
var Tooltip = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$animation = _ref.animation,
    animation = _ref$animation === void 0 ? 'slideDownLeft' : _ref$animation,
    style = _ref.style,
    getChildrenDOM = _ref.getChildrenDOM,
    children = _ref.children,
    onVisibleChange = _ref.onVisibleChange,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  var childrenRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });

  // 非受控显隐
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    visible = _useState2[0],
    setVisible = _useState2[1];

  // 受控显隐时, 需要更新容器位置
  useEffect(function () {
    if (visible) {
      updatePosition();
    }
    if (visible === null) return;
    typeof onVisibleChange === 'function' && onVisibleChange(visible);
  }, [visible]); // eslint-disable-line

  // 更新位置
  function updatePosition(source) {
    var _rootRef$current, _rootRef$current2, _rootRef$current3;
    // 源元素
    var sourceDOM = source;
    if (!sourceDOM) {
      var childrenDOM = childrenRef.current;
      if (typeof getChildrenDOM === 'function') {
        var _childrenDOM;
        childrenDOM = getChildrenDOM();
        if (typeof ((_childrenDOM = childrenDOM) === null || _childrenDOM === void 0 ? void 0 : _childrenDOM.getRootDOM) === 'function') {
          childrenDOM = childrenDOM.getRootDOM();
        }
      }
      sourceDOM = childrenDOM;
    }

    // 位移元素
    var targetDOM = rootRef !== null && rootRef !== void 0 && (_rootRef$current = rootRef.current) !== null && _rootRef$current !== void 0 && _rootRef$current.children && rootRef !== null && rootRef !== void 0 && (_rootRef$current2 = rootRef.current) !== null && _rootRef$current2 !== void 0 && _rootRef$current2.children[0] ? rootRef === null || rootRef === void 0 || (_rootRef$current3 = rootRef.current) === null || _rootRef$current3 === void 0 ? void 0 : _rootRef$current3.children[0] : null;
    if (sourceDOM && targetDOM) {
      // 没有自定义位置时生效
      if (!(style !== null && style !== void 0 && style.left) && !(style !== null && style !== void 0 && style.top) && !(style !== null && style !== void 0 && style.right) && !(style !== null && style !== void 0 && style.bottom)) {
        Utils.updateContainerPosition({
          source: sourceDOM,
          target: targetDOM,
          animation: animation,
          offset: {
            top: 8,
            bottom: 8
          }
        });
      }
    }
  }

  // 非受控显隐, 为子元素增加点击事件显隐
  var newChildren = React.Children.toArray(children);
  if (newChildren.length === 1) {
    newChildren = /*#__PURE__*/React.cloneElement(children, {
      ref: childrenRef,
      onClick: function onClick(e) {
        // 没有自定义位置时生效
        if (!(style !== null && style !== void 0 && style.left) && !(style !== null && style !== void 0 && style.top) && !(style !== null && style !== void 0 && style.right) && !(style !== null && style !== void 0 && style.bottom)) {
          updatePosition(e.currentTarget);
        }
        setVisible(!visible);
      }
    });
  } else {
    newChildren = children;
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Popup, _extends({
    animation: animation,
    style: style,
    visible: typeof visible === 'boolean' ? visible : visible,
    onVisibleChange: function onVisibleChange(newVisible) {
      if (!newVisible) {
        setVisible(newVisible);
      }
    }
  }, props, {
    ref: rootRef
  })), newChildren);
});
export default Tooltip;
